@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.012';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.013';
 use 5.010; use strict; use warnings;
 
 use Carp;
@@ -185,7 +185,8 @@ sub mdfile_2html {
   $cache_file =~ s/\///g;
   $cache_file = File::Spec->catfile(
                  $cache_dir,
-                 $cache_file . $options->{linkable_headers} . $options->{generate_toc});
+                 File::Spec->catfile(dirname($cache_file), basename($cache_file))
+                     . $options->{linkable_headers} . $options->{generate_toc});
 
   # check for cache hit
   if (-f $cache_file && $options->{cache}) {
@@ -276,7 +277,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
